nixio.exceptions package — Python reimplementation of NIXIO (http://g-node.github.io/nix/) 1.5.0 Development documentation

# nixio.exceptions package

## Submodules

## nixio.exceptions.exceptions module

exception nixio.exceptions.exceptions.DuplicateColumnName

  Bases: `Exception`

exception nixio.exceptions.exceptions.DuplicateName(caller, *args, **kwargs)

  Bases: `Exception`

exception nixio.exceptions.exceptions.IncompatibleDimensions(what, where)

  Bases: `ValueError`

exception nixio.exceptions.exceptions.InvalidAttrType(type_, value)

  Bases: `TypeError`

exception nixio.exceptions.exceptions.InvalidEntity(*args, **kwargs)

  Bases: `Exception`

exception nixio.exceptions.exceptions.InvalidFile

  Bases: `Exception`

exception nixio.exceptions.exceptions.InvalidUnit(what, where)

  Bases: `ValueError`

exception nixio.exceptions.exceptions.OutOfBounds(message, index=None)

  Bases: `IndexError`

exception nixio.exceptions.exceptions.UninitializedEntity(*args, **kwargs)

  Bases: `Exception`

exception nixio.exceptions.exceptions.UnsupportedLinkType(objtype, linktype)

  Bases: `Exception`

## Module contents

exception nixio.exceptions.DuplicateColumnName

  Bases: `Exception`

exception nixio.exceptions.DuplicateName(caller, *args, **kwargs)

  Bases: `Exception`

exception nixio.exceptions.IncompatibleDimensions(what, where)

  Bases: `ValueError`

exception nixio.exceptions.InvalidAttrType(type_, value)

  Bases: `TypeError`

exception nixio.exceptions.InvalidEntity(*args, **kwargs)

  Bases: `Exception`

exception nixio.exceptions.InvalidFile

  Bases: `Exception`

exception nixio.exceptions.InvalidUnit(what, where)

  Bases: `ValueError`

exception nixio.exceptions.OutOfBounds(message, index=None)

  Bases: `IndexError`

exception nixio.exceptions.UninitializedEntity(*args, **kwargs)

  Bases: `Exception`

exception nixio.exceptions.UnsupportedLinkType(objtype, linktype)

  Bases: `Exception`